@@ -1,6 +1,7 @@
 
 #define _GNU_SOURCE
+#include <config.h>
 #include "gdk_imlib.h"
 #include "gdk_imlib_private.h"
 
-ImlibData          *id;
+ImlibData          *_gdk_imlib_data;
